@@ -1,21 +1,38 @@
 (* Test the lowlevel interface to the database.
  * Assumes that $PGHOST, etc. are set to point to a database.
- * $Id: test_pgocaml_lowlevel.ml,v 1.1 2006/07/19 10:21:38 rich Exp $
+ *
+ * PG'OCaml - type safe interface to PostgreSQL.
+ * Copyright (C) 2005-2009 Richard Jones and other authors.
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this library; see the file COPYING.  If not, write to
+ * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  *)
 
 open Printf
 
 open ExtList
 
+let print_row i row =
+  printf "row %d: [%s]\n" i
+    (String.concat "; "
+      (List.map (function
+		| None -> "NULL"
+		| Some str -> sprintf "%S" str) row))
+
 let print_rows rows =
-  List.iteri (
-    fun i row ->
-      printf "row %d: [%s]\n" i
-	(String.concat "; "
-	   (List.map (function
-		      | None -> "NULL"
-		      | Some str -> sprintf "%S" str) row))
-  ) rows
+  List.iteri print_row rows
 
 let print_params_description params =
   printf "params:\n";
@@ -45,8 +62,8 @@ let () =
   let query = "select current_timestamp" in
   let name = "timestamp_query" in
   ignore (PGOCaml.prepare dbh ~query ~name ());
-  let rows = PGOCaml.execute dbh ~name ~params:[] () in
-  print_rows rows;
+  let i = ref 0 in
+  PGOCaml.cursor dbh ~name ~params:[] (fun row -> incr i; print_row !i row);
 
   (* Describe the statement. *)
   let params, results = PGOCaml.describe_statement dbh ~name () in
@@ -58,8 +75,8 @@ let () =
   let types = [ 23l; 23l ] in (* 23 = int4 *)
   let name = "sum_query" in
   ignore (PGOCaml.prepare dbh ~query ~name ~types ());
-  let rows = PGOCaml.execute dbh ~name ~params:[Some "1"; Some "2"] () in
-  print_rows rows;
+  let i = ref 0 in
+  PGOCaml.cursor dbh ~name ~params:[Some "1"; Some "2"] (fun row -> incr i; print_row !i row);
 
   (* Describe the statement. *)
   let params, results = PGOCaml.describe_statement dbh ~name () in
